)]}'
{"test/unit/obj/test_reconstructor.py":[{"author":{"_account_id":4608,"name":"Kota Tsuyuzaki","email":"bloodeagle40234@gmail.com","username":"tsuyuzaki-kota"},"change_message_id":"75333fe97f35c3f10cd24f5efea1b09d6aa45a10","unresolved":false,"context_lines":[{"line_number":1174,"context_line":"            def process_job(job):"},{"line_number":1175,"context_line":"                jobs.append(job)"},{"line_number":1176,"context_line":""},{"line_number":1177,"context_line":"            self.reconstructor.process_job \u003d process_job"},{"line_number":1178,"context_line":""},{"line_number":1179,"context_line":"            os.makedirs(os.path.join(self.devices, \u0027sda\u0027, \u0027objects-1\u0027, \u00270\u0027))"},{"line_number":1180,"context_line":"            self.reconstructor.run_once()"}],"source_content_type":"text/x-python","patch_set":1,"id":"9a629dbe_413c7d93","line":1177,"updated":"2016-11-08 06:32:27.000000000","message":"nits) i like to use mock.patch with \"with\" statement rather than assignment to save the original method. But i think this is safe because setUp method always call _configure_reconstructor() so the self.reconstructor will be always fresh.","commit_id":"f4adb2f28f5517772174aac18e3fe9ab1d08c913"},{"author":{"_account_id":4608,"name":"Kota Tsuyuzaki","email":"bloodeagle40234@gmail.com","username":"tsuyuzaki-kota"},"change_message_id":"75333fe97f35c3f10cd24f5efea1b09d6aa45a10","unresolved":false,"context_lines":[{"line_number":1177,"context_line":"            self.reconstructor.process_job \u003d process_job"},{"line_number":1178,"context_line":""},{"line_number":1179,"context_line":"            os.makedirs(os.path.join(self.devices, \u0027sda\u0027, \u0027objects-1\u0027, \u00270\u0027))"},{"line_number":1180,"context_line":"            self.reconstructor.run_once()"},{"line_number":1181,"context_line":"            self.assertEqual(1, len(jobs))"},{"line_number":1182,"context_line":""},{"line_number":1183,"context_line":"    def test_collect_parts_skips_non_ec_policy_and_device(self):"}],"source_content_type":"text/x-python","patch_set":1,"id":"9a629dbe_61ca61a3","line":1180,"updated":"2016-11-08 06:32:27.000000000","message":"Alright, if we hook the process_job above, we can hit the bug because it\u0027s related to collect_parts and stats_lines in before/after process_job and the hook works to skip the much wasted elapsed time in the test (in my feeling around 10 sec).\n\nNice.\n\nI confirmed the zero division error appeared at this line if I get rid of the fix line in the reconstructor.py","commit_id":"f4adb2f28f5517772174aac18e3fe9ab1d08c913"}]}
